.. -*- mode: rst -*-

Yellowbrick Contrib
===================

The ``yellowbrick.contrib`` package contains a variety of extra tools and experimental visualizers that are outside of core support or are still in development. Here is a listing of the contrib modules currently available:

.. toctree::
   :maxdepth: 2

   boundaries
   statsmodels
   scatter
   missing/index
